"""Implementation of XBAcompartment class.

Peter Schubert, HHU Duesseldorf, May 2022
"""

import sbmlxdf

from xbanalysis.utils.utils import xml_rba_ns
from xbanalysis.model.sbo_term import SboTerm


class XbaCompartment:

    def __init__(self, s_compartment):
        self.id = s_compartment.name
        self.name = s_compartment.get('name', self.id)
        if 'size' in s_compartment:
            self.size = s_compartment['size']
        if 'units' in s_compartment:
            self.units = s_compartment['units']
        if 'spatialDimension' in s_compartment:
            self.dimension = s_compartment['spatialDimension']
        if 'xmlAnnotation' in s_compartment:
            attrs = sbmlxdf.extract_xml_attrs(s_compartment['xmlAnnotation'], ns=xml_rba_ns, token='density')
            if 'frac_gcdw' in attrs:
                self.rba_frac_gcdw = float(attrs['frac_gcdw'])
        if ('sboterm' in s_compartment) and (type(s_compartment['sboterm']) is str):
            self.sboterm = SboTerm(s_compartment['sboterm'])
